@@ -9,13 +9,10 @@
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
-#    * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#    * See the License for the specific language governing permissions and
-#    * limitations under the License.
-
-"""
-Cloudify Cli Exceptions
-"""
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+############
 
 
 class CloudifyCliError(Exception):
@@ -34,7 +31,14 @@ class SuppressedCloudifyCliError(Exception):
     pass
 
 
-class ExecutionTimeoutError(Exception):
+class ExecutionTimeoutError(RuntimeError):
+
+    def __init__(self, execution_id, message):
+        self.execution_id = execution_id
+        self.message = message
+
+
+class EventProcessingTimeoutError(RuntimeError):
 
     def __init__(self, execution_id, message):
         self.execution_id = execution_id
